/*
 *
 * Copyright 2017 PingCAP, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.spark.sql.expression

import org.apache.spark.sql.BaseInitialOnceSuite

class LogicalAndOr0Suite extends BaseInitialOnceSuite {
  private val allCases = Seq[String](
    "select tp_char, tp_smallint, tp_char, tp_smallint, tp_char from full_data_type_table  where tp_char = tp_smallint and tp_char > 0",
    "select tp_char,tp_smallint from full_data_type_table  where tp_char = tp_smallint and tp_char > 0",
    "select tp_char,id_dt from full_data_type_table  where tp_char = id_dt and tp_char > 0",
    "select tp_nvarchar,tp_tinyint from full_data_type_table  where tp_nvarchar = tp_tinyint and tp_nvarchar > 0",
    "select tp_decimal,tp_double from full_data_type_table  where tp_decimal = tp_double and tp_decimal > 0",
    "select tp_double,tp_tinyint from full_data_type_table  where tp_double = tp_tinyint and tp_double > 0",
    "select tp_bigint,tp_float from full_data_type_table  where tp_bigint = tp_float and tp_bigint > 0",
    "select tp_float,tp_decimal from full_data_type_table  where tp_float = tp_decimal and tp_float > 0",
    "select tp_float,tp_smallint from full_data_type_table  where tp_float = tp_smallint and tp_float > 0",
    "select tp_varchar,tp_varchar from full_data_type_table  where tp_varchar = tp_varchar and tp_varchar > 0",
    "select tp_tinyint,tp_smallint from full_data_type_table  where tp_tinyint = tp_smallint and tp_tinyint > 0",
    "select tp_varchar,tp_float from full_data_type_table  where tp_varchar = tp_float and tp_varchar > 0",
    "select tp_real,id_dt from full_data_type_table  where tp_real = id_dt and tp_real > 0",
    "select tp_tinyint,tp_real from full_data_type_table  where tp_tinyint = tp_real and tp_tinyint > 0",
    "select tp_bigint,tp_real from full_data_type_table  where tp_bigint = tp_real and tp_bigint > 0",
    "select tp_char,tp_tinyint from full_data_type_table  where tp_char = tp_tinyint and tp_char > 0",
    "select tp_char,tp_timestamp from full_data_type_table  where tp_char = tp_timestamp and tp_char > 0",
    "select tp_real,tp_nvarchar from full_data_type_table  where tp_real = tp_nvarchar and tp_real > 0",
    "select tp_varchar,tp_tinyint from full_data_type_table  where tp_varchar = tp_tinyint and tp_varchar > 0",
    "select tp_decimal,tp_nvarchar from full_data_type_table  where tp_decimal = tp_nvarchar and tp_decimal > 0",
    "select tp_float,id_dt from full_data_type_table  where tp_float = id_dt and tp_float > 0",
    "select tp_real,tp_smallint from full_data_type_table  where tp_real = tp_smallint and tp_real > 0",
    "select tp_bigint,id_dt from full_data_type_table  where tp_bigint = id_dt and tp_bigint > 0",
    "select tp_bigint,tp_char from full_data_type_table  where tp_bigint = tp_char and tp_bigint > 0",
    "select tp_mediumint,tp_char from full_data_type_table  where tp_mediumint = tp_char and tp_mediumint > 0",
    "select tp_mediumint,tp_varchar from full_data_type_table  where tp_mediumint = tp_varchar and tp_mediumint > 0",
    "select tp_varchar,tp_datetime from full_data_type_table  where tp_varchar = tp_datetime and tp_varchar > 0",
    "select tp_real,tp_real from full_data_type_table  where tp_real = tp_real and tp_real > 0",
    "select tp_mediumint,tp_smallint from full_data_type_table  where tp_mediumint = tp_smallint and tp_mediumint > 0",
    "select tp_smallint,tp_real from full_data_type_table  where tp_smallint = tp_real and tp_smallint > 0",
    "select tp_char,tp_real from full_data_type_table  where tp_char = tp_real and tp_char > 0",
    "select tp_nvarchar,tp_mediumint from full_data_type_table  where tp_nvarchar = tp_mediumint and tp_nvarchar > 0",
    "select tp_double,tp_real from full_data_type_table  where tp_double = tp_real and tp_double > 0",
    "select tp_char,tp_bigint from full_data_type_table  where tp_char = tp_bigint and tp_char > 0",
    "select tp_float,tp_mediumint from full_data_type_table  where tp_float = tp_mediumint and tp_float > 0",
    "select tp_mediumint,tp_float from full_data_type_table  where tp_mediumint = tp_float and tp_mediumint > 0",
    "select tp_tinyint,tp_char from full_data_type_table  where tp_tinyint = tp_char and tp_tinyint > 0",
    "select tp_mediumint,tp_int from full_data_type_table  where tp_mediumint = tp_int and tp_mediumint > 0",
    "select id_dt,tp_nvarchar from full_data_type_table  where id_dt = tp_nvarchar and id_dt > 0",
    "select tp_tinyint,tp_decimal from full_data_type_table  where tp_tinyint = tp_decimal and tp_tinyint > 0",
    "select tp_int,tp_varchar from full_data_type_table  where tp_int = tp_varchar and tp_int > 0",
    "select tp_int,tp_smallint from full_data_type_table  where tp_int = tp_smallint and tp_int > 0",
    "select tp_nvarchar,tp_bigint from full_data_type_table  where tp_nvarchar = tp_bigint and tp_nvarchar > 0",
    "select tp_decimal,tp_char from full_data_type_table  where tp_decimal = tp_char and tp_decimal > 0",
    "select tp_mediumint,tp_decimal from full_data_type_table  where tp_mediumint = tp_decimal and tp_mediumint > 0",
    "select tp_decimal,tp_decimal from full_data_type_table  where tp_decimal = tp_decimal and tp_decimal > 0",
    "select id_dt,tp_int from full_data_type_table  where id_dt = tp_int and id_dt > 0",
    "select tp_decimal,tp_bigint from full_data_type_table  where tp_decimal = tp_bigint and tp_decimal > 0",
    "select tp_decimal,tp_int from full_data_type_table  where tp_decimal = tp_int and tp_decimal > 0",
    "select tp_float,tp_real from full_data_type_table  where tp_float = tp_real and tp_float > 0",
    "select tp_tinyint,tp_tinyint from full_data_type_table  where tp_tinyint = tp_tinyint and tp_tinyint > 0",
    "select tp_decimal,tp_float from full_data_type_table  where tp_decimal = tp_float and tp_decimal > 0",
    "select tp_double,tp_char from full_data_type_table  where tp_double = tp_char and tp_double > 0",
    "select tp_double,tp_float from full_data_type_table  where tp_double = tp_float and tp_double > 0",
    "select tp_smallint,tp_float from full_data_type_table  where tp_smallint = tp_float and tp_smallint > 0",
    "select tp_smallint,tp_decimal from full_data_type_table  where tp_smallint = tp_decimal and tp_smallint > 0",
    "select tp_int,tp_double from full_data_type_table  where tp_int = tp_double and tp_int > 0",
    "select tp_decimal,tp_smallint from full_data_type_table  where tp_decimal = tp_smallint and tp_decimal > 0",
    "select tp_mediumint,tp_bigint from full_data_type_table  where tp_mediumint = tp_bigint and tp_mediumint > 0",
    "select tp_tinyint,tp_mediumint from full_data_type_table  where tp_tinyint = tp_mediumint and tp_tinyint > 0",
    "select tp_mediumint,tp_nvarchar from full_data_type_table  where tp_mediumint = tp_nvarchar and tp_mediumint > 0",
    "select tp_bigint,tp_varchar from full_data_type_table  where tp_bigint = tp_varchar and tp_bigint > 0",
    "select tp_char,tp_float from full_data_type_table  where tp_char = tp_float and tp_char > 0",
    "select tp_nvarchar,tp_date from full_data_type_table  where tp_nvarchar = tp_date and tp_nvarchar > 0",
    "select tp_smallint,tp_bigint from full_data_type_table  where tp_smallint = tp_bigint and tp_smallint > 0",
    "select tp_varchar,tp_mediumint from full_data_type_table  where tp_varchar = tp_mediumint and tp_varchar > 0",
    "select tp_bigint,tp_bigint from full_data_type_table  where tp_bigint = tp_bigint and tp_bigint > 0",
    "select id_dt,tp_smallint from full_data_type_table  where id_dt = tp_smallint and id_dt > 0",
    "select tp_tinyint,tp_double from full_data_type_table  where tp_tinyint = tp_double and tp_tinyint > 0",
    "select tp_int,tp_int from full_data_type_table  where tp_int = tp_int and tp_int > 0",
    "select tp_char,tp_int from full_data_type_table  where tp_char = tp_int and tp_char > 0",
    "select tp_bigint,tp_double from full_data_type_table  where tp_bigint = tp_double and tp_bigint > 0",
    "select tp_nvarchar,tp_char from full_data_type_table  where tp_nvarchar = tp_char and tp_nvarchar > 0",
    "select tp_real,tp_double from full_data_type_table  where tp_real = tp_double and tp_real > 0",
    "select tp_varchar,tp_decimal from full_data_type_table  where tp_varchar = tp_decimal and tp_varchar > 0",
    "select tp_tinyint,id_dt from full_data_type_table  where tp_tinyint = id_dt and tp_tinyint > 0",
    "select tp_double,tp_varchar from full_data_type_table  where tp_double = tp_varchar and tp_double > 0",
    "select tp_int,tp_float from full_data_type_table  where tp_int = tp_float and tp_int > 0",
    "select tp_tinyint,tp_float from full_data_type_table  where tp_tinyint = tp_float and tp_tinyint > 0",
    "select tp_float,tp_int from full_data_type_table  where tp_float = tp_int and tp_float > 0",
    "select tp_int,tp_bigint from full_data_type_table  where tp_int = tp_bigint and tp_int > 0",
    "select tp_varchar,tp_smallint from full_data_type_table  where tp_varchar = tp_smallint and tp_varchar > 0",
    "select tp_varchar,tp_nvarchar from full_data_type_table  where tp_varchar = tp_nvarchar and tp_varchar > 0",
    "select id_dt,tp_bigint from full_data_type_table  where id_dt = tp_bigint and id_dt > 0",
    "select tp_bigint,tp_int from full_data_type_table  where tp_bigint = tp_int and tp_bigint > 0",
    "select tp_smallint,tp_mediumint from full_data_type_table  where tp_smallint = tp_mediumint and tp_smallint > 0",
    "select tp_nvarchar,tp_varchar from full_data_type_table  where tp_nvarchar = tp_varchar and tp_nvarchar > 0",
    "select tp_decimal,id_dt from full_data_type_table  where tp_decimal = id_dt and tp_decimal > 0",
    "select tp_decimal,tp_real from full_data_type_table  where tp_decimal = tp_real and tp_decimal > 0",
    "select tp_double,tp_nvarchar from full_data_type_table  where tp_double = tp_nvarchar and tp_double > 0",
    "select tp_smallint,tp_nvarchar from full_data_type_table  where tp_smallint = tp_nvarchar and tp_smallint > 0",
    "select tp_char,tp_date from full_data_type_table  where tp_char = tp_date and tp_char > 0",
    "select tp_int,tp_real from full_data_type_table  where tp_int = tp_real and tp_int > 0",
    "select tp_smallint,tp_char from full_data_type_table  where tp_smallint = tp_char and tp_smallint > 0",
    "select tp_float,tp_tinyint from full_data_type_table  where tp_float = tp_tinyint and tp_float > 0",
    "select id_dt,id_dt from full_data_type_table  where id_dt = id_dt and id_dt > 0",
    "select tp_real,tp_varchar from full_data_type_table  where tp_real = tp_varchar and tp_real > 0",
    "select tp_decimal,tp_varchar from full_data_type_table  where tp_decimal = tp_varchar and tp_decimal > 0",
    "select tp_int,id_dt from full_data_type_table  where tp_int = id_dt and tp_int > 0",
    "select tp_nvarchar,tp_float from full_data_type_table  where tp_nvarchar = tp_float and tp_nvarchar > 0",
    "select tp_mediumint,tp_real from full_data_type_table  where tp_mediumint = tp_real and tp_mediumint > 0",
    "select tp_nvarchar,tp_smallint from full_data_type_table  where tp_nvarchar = tp_smallint and tp_nvarchar > 0",
    "select tp_double,id_dt from full_data_type_table  where tp_double = id_dt and tp_double > 0",
    "select tp_float,tp_nvarchar from full_data_type_table  where tp_float = tp_nvarchar and tp_float > 0",
    "select tp_char,tp_datetime from full_data_type_table  where tp_char = tp_datetime and tp_char > 0",
    "select tp_varchar,tp_double from full_data_type_table  where tp_varchar = tp_double and tp_varchar > 0",
    "select tp_nvarchar,tp_double from full_data_type_table  where tp_nvarchar = tp_double and tp_nvarchar > 0",
    "select id_dt,tp_real from full_data_type_table  where id_dt = tp_real and id_dt > 0",
    "select tp_real,tp_int from full_data_type_table  where tp_real = tp_int and tp_real > 0",
    "select tp_char,tp_double from full_data_type_table  where tp_char = tp_double and tp_char > 0",
    "select tp_double,tp_mediumint from full_data_type_table  where tp_double = tp_mediumint and tp_double > 0",
    "select tp_real,tp_decimal from full_data_type_table  where tp_real = tp_decimal and tp_real > 0",
    "select tp_float,tp_varchar from full_data_type_table  where tp_float = tp_varchar and tp_float > 0",
    "select tp_varchar,tp_int from full_data_type_table  where tp_varchar = tp_int and tp_varchar > 0",
    "select tp_double,tp_smallint from full_data_type_table  where tp_double = tp_smallint and tp_double > 0",
    "select id_dt,tp_char from full_data_type_table  where id_dt = tp_char and id_dt > 0",
    "select tp_decimal,tp_mediumint from full_data_type_table  where tp_decimal = tp_mediumint and tp_decimal > 0",
    "select tp_char,tp_mediumint from full_data_type_table  where tp_char = tp_mediumint and tp_char > 0",
    "select tp_char,tp_nvarchar from full_data_type_table  where tp_char = tp_nvarchar and tp_char > 0",
    "select tp_tinyint,tp_bigint from full_data_type_table  where tp_tinyint = tp_bigint and tp_tinyint > 0",
    "select id_dt,tp_decimal from full_data_type_table  where id_dt = tp_decimal and id_dt > 0",
    "select tp_nvarchar,tp_timestamp from full_data_type_table  where tp_nvarchar = tp_timestamp and tp_nvarchar > 0",
    "select tp_smallint,tp_double from full_data_type_table  where tp_smallint = tp_double and tp_smallint > 0",
    "select tp_int,tp_mediumint from full_data_type_table  where tp_int = tp_mediumint and tp_int > 0",
    "select tp_smallint,tp_tinyint from full_data_type_table  where tp_smallint = tp_tinyint and tp_smallint > 0",
    "select id_dt,tp_float from full_data_type_table  where id_dt = tp_float and id_dt > 0",
    "select tp_char,tp_decimal from full_data_type_table  where tp_char = tp_decimal and tp_char > 0",
    "select tp_real,tp_char from full_data_type_table  where tp_real = tp_char and tp_real > 0",
    "select tp_int,tp_decimal from full_data_type_table  where tp_int = tp_decimal and tp_int > 0",
    "select tp_mediumint,tp_double from full_data_type_table  where tp_mediumint = tp_double and tp_mediumint > 0",
    "select tp_varchar,tp_real from full_data_type_table  where tp_varchar = tp_real and tp_varchar > 0",
    "select tp_bigint,tp_nvarchar from full_data_type_table  where tp_bigint = tp_nvarchar and tp_bigint > 0",
    "select tp_int,tp_nvarchar from full_data_type_table  where tp_int = tp_nvarchar and tp_int > 0",
    "select tp_char,tp_char from full_data_type_table  where tp_char = tp_char and tp_char > 0",
    "select tp_real,tp_float from full_data_type_table  where tp_real = tp_float and tp_real > 0",
    "select tp_mediumint,id_dt from full_data_type_table  where tp_mediumint = id_dt and tp_mediumint > 0",
    "select tp_nvarchar,tp_real from full_data_type_table  where tp_nvarchar = tp_real and tp_nvarchar > 0",
    "select tp_int,tp_tinyint from full_data_type_table  where tp_int = tp_tinyint and tp_int > 0",
    "select tp_mediumint,tp_mediumint from full_data_type_table  where tp_mediumint = tp_mediumint and tp_mediumint > 0",
    "select tp_nvarchar,tp_nvarchar from full_data_type_table  where tp_nvarchar = tp_nvarchar and tp_nvarchar > 0",
    "select tp_tinyint,tp_nvarchar from full_data_type_table  where tp_tinyint = tp_nvarchar and tp_tinyint > 0",
    "select tp_real,tp_mediumint from full_data_type_table  where tp_real = tp_mediumint and tp_real > 0",
    "select id_dt,tp_mediumint from full_data_type_table  where id_dt = tp_mediumint and id_dt > 0",
    "select tp_smallint,tp_varchar from full_data_type_table  where tp_smallint = tp_varchar and tp_smallint > 0",
    "select tp_varchar,id_dt from full_data_type_table  where tp_varchar = id_dt and tp_varchar > 0",
    "select id_dt,tp_double from full_data_type_table  where id_dt = tp_double and id_dt > 0",
    "select tp_smallint,id_dt from full_data_type_table  where tp_smallint = id_dt and tp_smallint > 0",
    "select id_dt,tp_varchar from full_data_type_table  where id_dt = tp_varchar and id_dt > 0",
    "select tp_bigint,tp_decimal from full_data_type_table  where tp_bigint = tp_decimal and tp_bigint > 0",
    "select tp_varchar,tp_date from full_data_type_table  where tp_varchar = tp_date and tp_varchar > 0",
    "select tp_tinyint,tp_int from full_data_type_table  where tp_tinyint = tp_int and tp_tinyint > 0",
    "select tp_double,tp_int from full_data_type_table  where tp_double = tp_int and tp_double > 0",
    "select tp_tinyint,tp_varchar from full_data_type_table  where tp_tinyint = tp_varchar and tp_tinyint > 0",
    "select tp_smallint,tp_smallint from full_data_type_table  where tp_smallint = tp_smallint and tp_smallint > 0",
    "select tp_nvarchar,tp_int from full_data_type_table  where tp_nvarchar = tp_int and tp_nvarchar > 0",
    "select tp_mediumint,tp_tinyint from full_data_type_table  where tp_mediumint = tp_tinyint and tp_mediumint > 0",
    "select tp_char,tp_varchar from full_data_type_table  where tp_char = tp_varchar and tp_char > 0",
    "select tp_smallint,tp_int from full_data_type_table  where tp_smallint = tp_int and tp_smallint > 0",
    "select tp_float,tp_bigint from full_data_type_table  where tp_float = tp_bigint and tp_float > 0",
    "select tp_double,tp_bigint from full_data_type_table  where tp_double = tp_bigint and tp_double > 0",
    "select tp_varchar,tp_timestamp from full_data_type_table  where tp_varchar = tp_timestamp and tp_varchar > 0",
    "select tp_varchar,tp_bigint from full_data_type_table  where tp_varchar = tp_bigint and tp_varchar > 0",
    "select tp_nvarchar,tp_decimal from full_data_type_table  where tp_nvarchar = tp_decimal and tp_nvarchar > 0",
    "select tp_nvarchar,tp_datetime from full_data_type_table  where tp_nvarchar = tp_datetime and tp_nvarchar > 0",
    "select tp_nvarchar,id_dt from full_data_type_table  where tp_nvarchar = id_dt and tp_nvarchar > 0",
    "select tp_int,tp_char from full_data_type_table  where tp_int = tp_char and tp_int > 0",
    "select tp_double,tp_decimal from full_data_type_table  where tp_double = tp_decimal and tp_double > 0",
    "select tp_double,tp_double from full_data_type_table  where tp_double = tp_double and tp_double > 0",
    "select tp_varchar,tp_char from full_data_type_table  where tp_varchar = tp_char and tp_varchar > 0",
    "select tp_bigint,tp_smallint from full_data_type_table  where tp_bigint = tp_smallint and tp_bigint > 0",
    "select tp_float,tp_char from full_data_type_table  where tp_float = tp_char and tp_float > 0",
    "select tp_bigint,tp_mediumint from full_data_type_table  where tp_bigint = tp_mediumint and tp_bigint > 0",
    "select tp_float,tp_double from full_data_type_table  where tp_float = tp_double and tp_float > 0",
    "select tp_bigint,tp_tinyint from full_data_type_table  where tp_bigint = tp_tinyint and tp_bigint > 0",
    "select id_dt,tp_tinyint from full_data_type_table  where id_dt = tp_tinyint and id_dt > 0",
    "select tp_decimal,tp_tinyint from full_data_type_table  where tp_decimal = tp_tinyint and tp_decimal > 0",
    "select tp_real,tp_bigint from full_data_type_table  where tp_real = tp_bigint and tp_real > 0",
    "select tp_float,tp_float from full_data_type_table  where tp_float = tp_float and tp_float > 0",
    "select tp_real,tp_tinyint from full_data_type_table  where tp_real = tp_tinyint and tp_real > 0",
    "select tp_nvarchar,tp_date from full_data_type_table  where tp_nvarchar = tp_date or tp_nvarchar > 0",
    "select tp_bigint,tp_mediumint from full_data_type_table  where tp_bigint = tp_mediumint or tp_bigint > 0",
    "select tp_varchar,tp_float from full_data_type_table  where tp_varchar = tp_float or tp_varchar > 0",
    "select tp_real,tp_real from full_data_type_table  where tp_real = tp_real or tp_real > 0",
    "select tp_decimal,tp_smallint from full_data_type_table  where tp_decimal = tp_smallint or tp_decimal > 0",
    "select tp_smallint,tp_decimal from full_data_type_table  where tp_smallint = tp_decimal or tp_smallint > 0",
    "select tp_char,tp_varchar from full_data_type_table  where tp_char = tp_varchar or tp_char > 0",
    "select tp_int,tp_decimal from full_data_type_table  where tp_int = tp_decimal or tp_int > 0",
    "select tp_decimal,tp_varchar from full_data_type_table  where tp_decimal = tp_varchar or tp_decimal > 0",
    "select tp_double,tp_varchar from full_data_type_table  where tp_double = tp_varchar or tp_double > 0",
    "select tp_int,id_dt from full_data_type_table  where tp_int = id_dt or tp_int > 0",
    "select tp_char,tp_float from full_data_type_table  where tp_char = tp_float or tp_char > 0",
    "select id_dt,tp_mediumint from full_data_type_table  where id_dt = tp_mediumint or id_dt > 0",
    "select tp_int,tp_bigint from full_data_type_table  where tp_int = tp_bigint or tp_int > 0",
    "select tp_double,tp_decimal from full_data_type_table  where tp_double = tp_decimal or tp_double > 0",
    "select tp_double,tp_nvarchar from full_data_type_table  where tp_double = tp_nvarchar or tp_double > 0",
    "select tp_char,tp_mediumint from full_data_type_table  where tp_char = tp_mediumint or tp_char > 0",
    "select tp_char,tp_date from full_data_type_table  where tp_char = tp_date or tp_char > 0",
    "select id_dt,tp_varchar from full_data_type_table  where id_dt = tp_varchar or id_dt > 0",
    "select tp_tinyint,tp_int from full_data_type_table  where tp_tinyint = tp_int or tp_tinyint > 0",
    "select tp_float,tp_smallint from full_data_type_table  where tp_float = tp_smallint or tp_float > 0",
    "select tp_nvarchar,tp_smallint from full_data_type_table  where tp_nvarchar = tp_smallint or tp_nvarchar > 0",
    "select tp_mediumint,id_dt from full_data_type_table  where tp_mediumint = id_dt or tp_mediumint > 0",
    "select tp_varchar,id_dt from full_data_type_table  where tp_varchar = id_dt or tp_varchar > 0",
    "select tp_tinyint,tp_decimal from full_data_type_table  where tp_tinyint = tp_decimal or tp_tinyint > 0",
    "select tp_decimal,tp_int from full_data_type_table  where tp_decimal = tp_int or tp_decimal > 0",
    "select tp_varchar,tp_nvarchar from full_data_type_table  where tp_varchar = tp_nvarchar or tp_varchar > 0",
    "select tp_char,tp_timestamp from full_data_type_table  where tp_char = tp_timestamp or tp_char > 0",
    "select tp_mediumint,tp_tinyint from full_data_type_table  where tp_mediumint = tp_tinyint or tp_mediumint > 0",
    "select tp_double,id_dt from full_data_type_table  where tp_double = id_dt or tp_double > 0",
    "select tp_decimal,tp_mediumint from full_data_type_table  where tp_decimal = tp_mediumint or tp_decimal > 0",
    "select tp_smallint,tp_float from full_data_type_table  where tp_smallint = tp_float or tp_smallint > 0",
    "select tp_float,tp_int from full_data_type_table  where tp_float = tp_int or tp_float > 0",
    "select tp_mediumint,tp_float from full_data_type_table  where tp_mediumint = tp_float or tp_mediumint > 0",
    "select tp_nvarchar,tp_double from full_data_type_table  where tp_nvarchar = tp_double or tp_nvarchar > 0",
    "select tp_real,tp_bigint from full_data_type_table  where tp_real = tp_bigint or tp_real > 0",
    "select tp_varchar,tp_double from full_data_type_table  where tp_varchar = tp_double or tp_varchar > 0",
    "select tp_float,tp_nvarchar from full_data_type_table  where tp_float = tp_nvarchar or tp_float > 0",
    "select tp_varchar,tp_datetime from full_data_type_table  where tp_varchar = tp_datetime or tp_varchar > 0",
    "select tp_int,tp_int from full_data_type_table  where tp_int = tp_int or tp_int > 0",
    "select id_dt,tp_bigint from full_data_type_table  where id_dt = tp_bigint or id_dt > 0",
    "select tp_nvarchar,tp_real from full_data_type_table  where tp_nvarchar = tp_real or tp_nvarchar > 0",
    "select tp_int,tp_nvarchar from full_data_type_table  where tp_int = tp_nvarchar or tp_int > 0",
    "select tp_decimal,tp_char from full_data_type_table  where tp_decimal = tp_char or tp_decimal > 0",
    "select tp_tinyint,tp_bigint from full_data_type_table  where tp_tinyint = tp_bigint or tp_tinyint > 0",
    "select tp_bigint,tp_varchar from full_data_type_table  where tp_bigint = tp_varchar or tp_bigint > 0",
    "select tp_int,tp_smallint from full_data_type_table  where tp_int = tp_smallint or tp_int > 0",
    "select tp_nvarchar,tp_mediumint from full_data_type_table  where tp_nvarchar = tp_mediumint or tp_nvarchar > 0",
    "select tp_bigint,tp_float from full_data_type_table  where tp_bigint = tp_float or tp_bigint > 0",
    "select tp_nvarchar,tp_decimal from full_data_type_table  where tp_nvarchar = tp_decimal or tp_nvarchar > 0",
    "select tp_real,tp_mediumint from full_data_type_table  where tp_real = tp_mediumint or tp_real > 0",
    "select tp_decimal,tp_tinyint from full_data_type_table  where tp_decimal = tp_tinyint or tp_decimal > 0",
    "select tp_float,tp_decimal from full_data_type_table  where tp_float = tp_decimal or tp_float > 0",
    "select tp_smallint,tp_char from full_data_type_table  where tp_smallint = tp_char or tp_smallint > 0",
    "select tp_char,tp_int from full_data_type_table  where tp_char = tp_int or tp_char > 0",
    "select tp_tinyint,tp_nvarchar from full_data_type_table  where tp_tinyint = tp_nvarchar or tp_tinyint > 0",
    "select tp_nvarchar,tp_timestamp from full_data_type_table  where tp_nvarchar = tp_timestamp or tp_nvarchar > 0",
    "select id_dt,tp_char from full_data_type_table  where id_dt = tp_char or id_dt > 0",
    "select tp_int,tp_double from full_data_type_table  where tp_int = tp_double or tp_int > 0",
    "select tp_decimal,tp_double from full_data_type_table  where tp_decimal = tp_double or tp_decimal > 0",
    "select tp_mediumint,tp_decimal from full_data_type_table  where tp_mediumint = tp_decimal or tp_mediumint > 0",
    "select tp_mediumint,tp_varchar from full_data_type_table  where tp_mediumint = tp_varchar or tp_mediumint > 0",
    "select tp_varchar,tp_mediumint from full_data_type_table  where tp_varchar = tp_mediumint or tp_varchar > 0",
    "select tp_nvarchar,tp_int from full_data_type_table  where tp_nvarchar = tp_int or tp_nvarchar > 0",
    "select tp_real,tp_nvarchar from full_data_type_table  where tp_real = tp_nvarchar or tp_real > 0",
    "select id_dt,tp_int from full_data_type_table  where id_dt = tp_int or id_dt > 0",
    "select tp_double,tp_real from full_data_type_table  where tp_double = tp_real or tp_double > 0",
    "select tp_varchar,tp_timestamp from full_data_type_table  where tp_varchar = tp_timestamp or tp_varchar > 0",
    "select tp_int,tp_char from full_data_type_table  where tp_int = tp_char or tp_int > 0",
    "select tp_mediumint,tp_smallint from full_data_type_table  where tp_mediumint = tp_smallint or tp_mediumint > 0",
    "select tp_nvarchar,tp_tinyint from full_data_type_table  where tp_nvarchar = tp_tinyint or tp_nvarchar > 0",
    "select tp_int,tp_mediumint from full_data_type_table  where tp_int = tp_mediumint or tp_int > 0",
    "select tp_int,tp_real from full_data_type_table  where tp_int = tp_real or tp_int > 0",
    "select tp_varchar,tp_date from full_data_type_table  where tp_varchar = tp_date or tp_varchar > 0",
    "select tp_char,tp_datetime from full_data_type_table  where tp_char = tp_datetime or tp_char > 0",
    "select tp_bigint,tp_real from full_data_type_table  where tp_bigint = tp_real or tp_bigint > 0",
    "select tp_mediumint,tp_nvarchar from full_data_type_table  where tp_mediumint = tp_nvarchar or tp_mediumint > 0",
    "select tp_smallint,tp_varchar from full_data_type_table  where tp_smallint = tp_varchar or tp_smallint > 0",
    "select tp_real,tp_char from full_data_type_table  where tp_real = tp_char or tp_real > 0",
    "select tp_real,tp_int from full_data_type_table  where tp_real = tp_int or tp_real > 0",
    "select tp_tinyint,tp_double from full_data_type_table  where tp_tinyint = tp_double or tp_tinyint > 0",
    "select tp_bigint,tp_nvarchar from full_data_type_table  where tp_bigint = tp_nvarchar or tp_bigint > 0",
    "select tp_mediumint,tp_char from full_data_type_table  where tp_mediumint = tp_char or tp_mediumint > 0",
    "select tp_varchar,tp_varchar from full_data_type_table  where tp_varchar = tp_varchar or tp_varchar > 0",
    "select tp_nvarchar,tp_datetime from full_data_type_table  where tp_nvarchar = tp_datetime or tp_nvarchar > 0",
    "select tp_real,tp_varchar from full_data_type_table  where tp_real = tp_varchar or tp_real > 0",
    "select tp_float,tp_float from full_data_type_table  where tp_float = tp_float or tp_float > 0",
    "select tp_double,tp_char from full_data_type_table  where tp_double = tp_char or tp_double > 0",
    "select tp_nvarchar,id_dt from full_data_type_table  where tp_nvarchar = id_dt or tp_nvarchar > 0",
    "select tp_double,tp_int from full_data_type_table  where tp_double = tp_int or tp_double > 0",
    "select id_dt,id_dt from full_data_type_table  where id_dt = id_dt or id_dt > 0",
    "select tp_char,tp_nvarchar from full_data_type_table  where tp_char = tp_nvarchar or tp_char > 0",
    "select tp_real,tp_double from full_data_type_table  where tp_real = tp_double or tp_real > 0",
    "select id_dt,tp_nvarchar from full_data_type_table  where id_dt = tp_nvarchar or id_dt > 0",
    "select tp_varchar,tp_real from full_data_type_table  where tp_varchar = tp_real or tp_varchar > 0",
    "select tp_nvarchar,tp_nvarchar from full_data_type_table  where tp_nvarchar = tp_nvarchar or tp_nvarchar > 0",
    "select tp_char,tp_tinyint from full_data_type_table  where tp_char = tp_tinyint or tp_char > 0",
    "select tp_char,tp_double from full_data_type_table  where tp_char = tp_double or tp_char > 0",
    "select tp_mediumint,tp_bigint from full_data_type_table  where tp_mediumint = tp_bigint or tp_mediumint > 0",
    "select tp_double,tp_tinyint from full_data_type_table  where tp_double = tp_tinyint or tp_double > 0",
    "select tp_int,tp_varchar from full_data_type_table  where tp_int = tp_varchar or tp_int > 0",
    "select tp_decimal,tp_decimal from full_data_type_table  where tp_decimal = tp_decimal or tp_decimal > 0",
    "select tp_float,tp_double from full_data_type_table  where tp_float = tp_double or tp_float > 0",
    "select tp_float,tp_mediumint from full_data_type_table  where tp_float = tp_mediumint or tp_float > 0",
    "select tp_varchar,tp_smallint from full_data_type_table  where tp_varchar = tp_smallint or tp_varchar > 0",
    "select tp_nvarchar,tp_float from full_data_type_table  where tp_nvarchar = tp_float or tp_nvarchar > 0",
    "select tp_real,tp_smallint from full_data_type_table  where tp_real = tp_smallint or tp_real > 0",
    "select tp_tinyint,tp_varchar from full_data_type_table  where tp_tinyint = tp_varchar or tp_tinyint > 0",
    "select tp_bigint,tp_decimal from full_data_type_table  where tp_bigint = tp_decimal or tp_bigint > 0",
    "select tp_bigint,tp_int from full_data_type_table  where tp_bigint = tp_int or tp_bigint > 0",
    "select tp_mediumint,tp_double from full_data_type_table  where tp_mediumint = tp_double or tp_mediumint > 0",
    "select tp_bigint,tp_char from full_data_type_table  where tp_bigint = tp_char or tp_bigint > 0",
    "select tp_nvarchar,tp_varchar from full_data_type_table  where tp_nvarchar = tp_varchar or tp_nvarchar > 0",
    "select tp_bigint,tp_smallint from full_data_type_table  where tp_bigint = tp_smallint or tp_bigint > 0",
    "select tp_float,id_dt from full_data_type_table  where tp_float = id_dt or tp_float > 0",
    "select tp_decimal,tp_float from full_data_type_table  where tp_decimal = tp_float or tp_decimal > 0",
    "select tp_varchar,tp_tinyint from full_data_type_table  where tp_varchar = tp_tinyint or tp_varchar > 0",
    "select tp_mediumint,tp_mediumint from full_data_type_table  where tp_mediumint = tp_mediumint or tp_mediumint > 0",
    "select tp_varchar,tp_bigint from full_data_type_table  where tp_varchar = tp_bigint or tp_varchar > 0",
    "select tp_int,tp_tinyint from full_data_type_table  where tp_int = tp_tinyint or tp_int > 0",
    "select tp_smallint,tp_smallint from full_data_type_table  where tp_smallint = tp_smallint or tp_smallint > 0",
    "select tp_real,tp_tinyint from full_data_type_table  where tp_real = tp_tinyint or tp_real > 0",
    "select tp_double,tp_double from full_data_type_table  where tp_double = tp_double or tp_double > 0",
    "select tp_smallint,tp_real from full_data_type_table  where tp_smallint = tp_real or tp_smallint > 0",
    "select tp_bigint,tp_tinyint from full_data_type_table  where tp_bigint = tp_tinyint or tp_bigint > 0",
    "select tp_decimal,tp_bigint from full_data_type_table  where tp_decimal = tp_bigint or tp_decimal > 0",
    "select tp_tinyint,tp_char from full_data_type_table  where tp_tinyint = tp_char or tp_tinyint > 0",
    "select tp_char,id_dt from full_data_type_table  where tp_char = id_dt or tp_char > 0",
    "select tp_tinyint,tp_smallint from full_data_type_table  where tp_tinyint = tp_smallint or tp_tinyint > 0",
    "select tp_char,tp_smallint from full_data_type_table  where tp_char = tp_smallint or tp_char > 0",
    "select tp_float,tp_varchar from full_data_type_table  where tp_float = tp_varchar or tp_float > 0",
    "select tp_float,tp_tinyint from full_data_type_table  where tp_float = tp_tinyint or tp_float > 0",
    "select id_dt,tp_tinyint from full_data_type_table  where id_dt = tp_tinyint or id_dt > 0",
    "select tp_smallint,tp_bigint from full_data_type_table  where tp_smallint = tp_bigint or tp_smallint > 0",
    "select tp_bigint,id_dt from full_data_type_table  where tp_bigint = id_dt or tp_bigint > 0",
    "select id_dt,tp_double from full_data_type_table  where id_dt = tp_double or id_dt > 0",
    "select tp_smallint,tp_int from full_data_type_table  where tp_smallint = tp_int or tp_smallint > 0",
    "select tp_bigint,tp_double from full_data_type_table  where tp_bigint = tp_double or tp_bigint > 0",
    "select tp_tinyint,tp_tinyint from full_data_type_table  where tp_tinyint = tp_tinyint or tp_tinyint > 0",
    "select tp_tinyint,tp_real from full_data_type_table  where tp_tinyint = tp_real or tp_tinyint > 0",
    "select tp_smallint,tp_double from full_data_type_table  where tp_smallint = tp_double or tp_smallint > 0",
    "select tp_char,tp_bigint from full_data_type_table  where tp_char = tp_bigint or tp_char > 0",
    "select tp_char,tp_decimal from full_data_type_table  where tp_char = tp_decimal or tp_char > 0",
    "select tp_real,id_dt from full_data_type_table  where tp_real = id_dt or tp_real > 0",
    "select tp_double,tp_bigint from full_data_type_table  where tp_double = tp_bigint or tp_double > 0",
    "select tp_float,tp_char from full_data_type_table  where tp_float = tp_char or tp_float > 0",
    "select tp_varchar,tp_char from full_data_type_table  where tp_varchar = tp_char or tp_varchar > 0",
    "select tp_nvarchar,tp_char from full_data_type_table  where tp_nvarchar = tp_char or tp_nvarchar > 0",
    "select tp_smallint,tp_nvarchar from full_data_type_table  where tp_smallint = tp_nvarchar or tp_smallint > 0",
    "select tp_smallint,id_dt from full_data_type_table  where tp_smallint = id_dt or tp_smallint > 0",
    "select tp_tinyint,tp_float from full_data_type_table  where tp_tinyint = tp_float or tp_tinyint > 0",
    "select tp_tinyint,tp_mediumint from full_data_type_table  where tp_tinyint = tp_mediumint or tp_tinyint > 0",
    "select id_dt,tp_decimal from full_data_type_table  where id_dt = tp_decimal or id_dt > 0",
    "select tp_double,tp_float from full_data_type_table  where tp_double = tp_float or tp_double > 0",
    "select tp_tinyint,id_dt from full_data_type_table  where tp_tinyint = id_dt or tp_tinyint > 0",
    "select tp_bigint,tp_bigint from full_data_type_table  where tp_bigint = tp_bigint or tp_bigint > 0",
    "select tp_mediumint,tp_real from full_data_type_table  where tp_mediumint = tp_real or tp_mediumint > 0",
    "select id_dt,tp_float from full_data_type_table  where id_dt = tp_float or id_dt > 0",
    "select tp_smallint,tp_tinyint from full_data_type_table  where tp_smallint = tp_tinyint or tp_smallint > 0",
    "select tp_decimal,tp_real from full_data_type_table  where tp_decimal = tp_real or tp_decimal > 0",
    "select tp_double,tp_mediumint from full_data_type_table  where tp_double = tp_mediumint or tp_double > 0",
    "select tp_smallint,tp_mediumint from full_data_type_table  where tp_smallint = tp_mediumint or tp_smallint > 0",
    "select tp_varchar,tp_int from full_data_type_table  where tp_varchar = tp_int or tp_varchar > 0",
    "select tp_char,tp_real from full_data_type_table  where tp_char = tp_real or tp_char > 0",
    "select tp_real,tp_float from full_data_type_table  where tp_real = tp_float or tp_real > 0",
    "select tp_decimal,tp_nvarchar from full_data_type_table  where tp_decimal = tp_nvarchar or tp_decimal > 0",
    "select tp_int,tp_float from full_data_type_table  where tp_int = tp_float or tp_int > 0",
    "select id_dt,tp_real from full_data_type_table  where id_dt = tp_real or id_dt > 0",
    "select tp_real,tp_decimal from full_data_type_table  where tp_real = tp_decimal or tp_real > 0",
    "select tp_varchar,tp_decimal from full_data_type_table  where tp_varchar = tp_decimal or tp_varchar > 0",
    "select tp_decimal,id_dt from full_data_type_table  where tp_decimal = id_dt or tp_decimal > 0",
    "select tp_float,tp_real from full_data_type_table  where tp_float = tp_real or tp_float > 0",
    "select id_dt,tp_smallint from full_data_type_table  where id_dt = tp_smallint or id_dt > 0",
    "select tp_nvarchar,tp_bigint from full_data_type_table  where tp_nvarchar = tp_bigint or tp_nvarchar > 0",
    "select tp_float,tp_bigint from full_data_type_table  where tp_float = tp_bigint or tp_float > 0",
    "select tp_char,tp_char from full_data_type_table  where tp_char = tp_char or tp_char > 0",
    "select tp_mediumint,tp_int from full_data_type_table  where tp_mediumint = tp_int or tp_mediumint > 0",
    "select tp_double,tp_smallint from full_data_type_table  where tp_double = tp_smallint or tp_double > 0"
  ).map(_.concat(" order by id_dt"))

  allCases foreach { query =>
    {
      test(query) {
        runTest(query)
      }
    }
  }

}
